def addition(a,b):
    return a+b 

def subtraction(a,b):
    return a-b 

def str_to_int(given_list):
    int_list = []
    for i in given_list:
        int_list.append(int(i))
    return int_list


def int_to_str(given_list):
    str_list = []
    for i in given_list:
        str_list.append(str(i))
    return str_list